# STOW TUI

<p align="center">
<a href='#license'><img src='https://img.shields.io/github/license/ypraw/stowtui?color=brightgreen&logo=github&style=for-the-badge' alt='license'/></a>
<a href='#stars'><img src='https://img.shields.io/github/stars/ypraw/stowtui?style=for-the-badge' alt='stars'/></a>
<a href='#pypi'><img src='https://img.shields.io/pypi/v/stowtui?label=pypi&style=for-the-badge' alt='size'/></a>
<a href='#python'><img src="https://img.shields.io/pypi/pyversions/stowtui?color=brightgreen&label=Python%20Version&logo=python&logoColor=yellow&style=for-the-badge">
</p>

## DESCRIPTION

_stow tui is a Terminal User Interface Program for [GNU STOW](https://www.gnu.org/software/stow/)_

## HOW TO INSTALL

* if you want to edit or modify source code

    Clone this repository,

    ```bash
    git clone https://github.com/ypraw/stowtui.git
    ```

    then run the installer script,

    ```bash
    source ./install.sh
    ```

* install from pypi.org (using pip)

    ```bash
    pip install stowtui
    ```

* install from AUR for archlinux users (using paru)

    ```bash
    paru -S stowtui-git
    ```

* install from PKGBUILD for archlinux users (using makepkg)

    ```bash
    git clone https://github.com/ypraw/stowtui.git
    cd aur
    makepkg -si
    ```

## AUTHOR

* [Yunindyo Prabowo](https://github.com/ypraw)

## CONTRIBUTORS

<a href = "https://github.com/ypraw/stowtui/graphs/contributors">
  <img src = "https://contrib.rocks/image?repo=ypraw/stowtui"/>
</a>

## CONTRIBUTING

* Fork the repo
* Create your feature branch (git checkout -b feature/fooBar)
* Commit your changes (git commit -am 'Add some fooBar')
* Push to the branch (git push origin feature/fooBar)
* Create a new Pull Request

## TO DO

* [x] Restow Packages
* [x] Delete a package from the target tree
* [ ] sudo action if any special access to root tree
* [ ] complete manual instructions

## LICENSE

* [npyscreen](https://github.com/npcole/npyscreen) Copyright (c) 2004--2009, Nicholas P. S. Cole (n@npcole.com)

* [gnu/stow](https://www.gnu.org/software/stow/) Copyright © 2016 Free Software Foundation, Inc.

* [StowTUI](https://github.com/ypraw/stowtui) Copyright 2021 Yunindyo Prabowo

_**All Codes in this repository is licensed under GPL V3**_
-----
    Stow TUI is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Stow TUI is distributed in the hope that it will be useful,

    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Stow TUI. If not, see <http://www.gnu.org/licenses/>.
-----
